pub unsafe trait SKViewDelegate: NSObjectProtocol {
// Provided method
unsafe fn view_shouldRenderAtTime(
&self,
view: &SKView,
time: NSTimeInterval,
) -> bool
where Self: Sized + Message { ... }
}Available on crate feature
SKView only.Expand description
Provided Methods
Sourceunsafe fn view_shouldRenderAtTime(
&self,
view: &SKView,
time: NSTimeInterval,
) -> bool
Available on macOS and crate feature objc2-app-kit only.
unsafe fn view_shouldRenderAtTime( &self, view: &SKView, time: NSTimeInterval, ) -> bool
objc2-app-kit only.Allows the client to dynamically control the render rate.
return YES to initiate an update and render for the target time. return NO to skip update and render for this target time.